package com.example.bywin.cloud.server.example.access;

import com.bywin.cloud.boot.annatation.BywinCloudRest;
import com.bywin.cloud.security.core.context.BywinCloudUserContextHolder;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;

import java.util.Set;

/**
 * 部门数据权限示例api
 *
 * @author xie40
 * create time: 2023-06-15 16:53
 */
@Tag(name = "部门数据权限")
@BywinCloudRest("/dept-data")
public class DeptDataPermissionExampleApi {


    @Operation(summary = "按权限查询当前用户拥有的部门权限")
    @GetMapping("/permission/{permission}")
    public String getAccessibleDepartmentsByPermission(@PathVariable("permission") String permission) {

        final Set<Long> deptIds = BywinCloudUserContextHolder.getUser().getAccessibleDepartmentsByPermission(permission);

        // 部门数据权限常用于sql， eg： where dept_id in (1, 2, 3)
        return StringUtils.join(",", deptIds);

    }

    @Operation(summary = "按角色查询当前用户拥有的部门权限")
    @GetMapping("/role/{role}")
    public String getAccessibleDepartmentsByRole(@PathVariable("role") String role) {

        final Set<Long> deptIds = BywinCloudUserContextHolder.getUser().getAccessibleDepartmentsByRole(role);
        // 部门数据权限常用于sql， eg： where dept_id in (1, 2, 3)
        return StringUtils.join(",", deptIds);

    }


}
