package com.example.bywin.cloud.server.example.cache;

import com.bywin.cloud.boot.annatation.BywinCloudRest;
import com.example.bywin.cloud.server.example.cache.biz.SpringCacheExampleBiz;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.enums.ParameterIn;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.ResponseBody;

/**
 * @author xie40
 * create time: 2023-06-12 14:26
 */
@BywinCloudRest("/cache")
@Tag(name = "缓存测试")
@Slf4j
public class BywinCloudCacheExample {

    private final SpringCacheExampleBiz springCacheExampleBiz;

    public BywinCloudCacheExample(SpringCacheExampleBiz springCacheExampleBiz) {
        this.springCacheExampleBiz = springCacheExampleBiz;
    }

    /**
     * 文档参考spring cache
     * <a href="https://docs.spring.io/spring-framework/reference/integration/cache/annotations.html#cache-annotations-cacheable-default-cache-resolver">...</a>
     */
    @Operation(summary = "缓存注解@Cacheable测试")
    @GetMapping(value = "/cache/{key}/{defaultValue}")
    public Object cacheValue(
            @Parameter(in = ParameterIn.PATH, name = "key", description = "缓存key")
            @PathVariable("key") String key,
            @Parameter(in = ParameterIn.PATH, name = "defaultValue", description = "缓存默认value，下次访问还是这个值")
            @PathVariable("defaultValue") String defaultValue) {

        return springCacheExampleBiz.getByCacheableAnnotation(key, defaultValue);
    }


    @Operation(summary = "缓存编程测试")
    @GetMapping("/get/{key}/{value}")
    @ResponseBody
    public Object get(
            @Parameter(in = ParameterIn.PATH, name = "key", description = "缓存key")
            @PathVariable("key") String key,
            @Parameter(in = ParameterIn.PATH, name = "value", description = "缓存值")
            @PathVariable("value") String value) {

        return springCacheExampleBiz.getByCode(key, value);
    }



}
