package com.example.bywin.cloud.server.example.cache.biz;

import org.springframework.cache.Cache;
import org.springframework.cache.CacheManager;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Component;

/**
 * @author xie40
 * create time: 2023-07-17 11:08
 */
@Component
public class SpringCacheExampleBiz {

    public static final String BYWIN_CLOUD_CACHE_TEST_NAME = "bywin-cloud-cache-test";


    private final Cache cache;

    public SpringCacheExampleBiz(CacheManager cacheManager) {
        this.cache = cacheManager.getCache(BYWIN_CLOUD_CACHE_TEST_NAME);
    }

    /**
     * 缓存注解测试
     *
     * @param key          key
     * @param defaultValue 默认值
     * @return 如有缓存获取缓存值，没有获取默认值
     */
    @Cacheable(cacheNames = SpringCacheExampleBiz.BYWIN_CLOUD_CACHE_TEST_NAME, key = "#key")
    public String getByCacheableAnnotation(String key, String defaultValue) {
        return defaultValue;
    }


    public String getByCode(String key, String defaultValue) {
        final Cache.ValueWrapper valueWrapper = cache.get(key);

        if (valueWrapper != null) {
            return (String) valueWrapper.get();
        }

        cache.put(key, defaultValue);

        return defaultValue;
    }


}
