package com.example.bywin.cloud.server.example.client;

import com.bywin.cloud.boot.annatation.BywinCloudRest;
import com.bywin.cloud.client.services.clients.system.BywinCloudSystemDeptClient;
import com.bywin.cloud.client.services.clients.system.domain.SysDept;
import com.bywin.cloud.web.response.BywinCloudResponse;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.SpringQueryMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Slf4j
@Tag(name = "认证部门示例api")
@BywinCloudRest(value = "/")
@RequiredArgsConstructor
public class SystemDeptExample {
    private final BywinCloudSystemDeptClient deptClient;

    /**
     * 部门列表
     *
     * @param dept
     * @return
     */
    @GetMapping("/dept/listR")
    public List<SysDept> listR(@SpringQueryMap SysDept dept) {
        dept.setApplicationId(0L);

        return deptClient.listR(dept);
    }

    /**
     * 部门详情
     *
     * @param deptId
     * @return
     */
    @GetMapping(value = "/dept/getById")
    public BywinCloudResponse<SysDept> getById(@RequestParam("deptId") Long deptId) {
        return deptClient.getById(deptId);
    }

    /**
     * 添加部门
     *
     * @param dept
     * @return
     */
    @PostMapping("/dept")
    public BywinCloudResponse<Long> add(@RequestBody SysDept dept) {
        return deptClient.add(dept);
    }

    /**
     * 更新部门
     *
     * @param dept
     * @return
     */
    @PutMapping("/dept")
    public BywinCloudResponse<?> edit(@RequestBody SysDept dept) {
        return deptClient.edit(dept);
    }

    /**
     * 删除部门
     *
     * @param deptId
     * @param applicationId
     * @return
     */
    @DeleteMapping("/dept/{deptId}")
    public BywinCloudResponse<?> remove(@PathVariable("deptId") Long deptId, @RequestParam(value = "applicationId", required = false) Long applicationId) {
        return deptClient.remove(deptId, applicationId);
    }

}

