package com.example.bywin.cloud.server.example.client;

import com.bywin.cloud.boot.annatation.BywinCloudRest;
import com.bywin.cloud.client.services.clients.system.BywinCloudSystemUserClient;
import com.bywin.cloud.client.services.clients.system.domain.SysUser;
import com.bywin.cloud.client.services.clients.system.domain.SysUserRole;
import com.bywin.cloud.client.services.clients.system.request.SysUserRoleAppDeptRequest;
import com.bywin.cloud.client.services.clients.system.request.SysUserSearchRequest;
import com.bywin.cloud.web.response.BywinCloudPageResponse;
import com.bywin.cloud.web.response.BywinCloudResponse;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

@Slf4j
@Tag(name = "认证部门示例api")
@BywinCloudRest(value = "/")
@RequiredArgsConstructor
public class SystemUserExample {
    private final BywinCloudSystemUserClient userClient;

    /**
     * 用户列表 不分页
     */
    @PostMapping("/user/listUserBySearchR")
    BywinCloudResponse<SysUser> listUserBySearchR(@RequestBody SysUserSearchRequest params) {
        //params.setUserName("admin");
        return userClient.listUserBySearchR(params);
    }

    /**
     * 用户列表 分页
     */
    @PostMapping("/user/listUserBySearchPage")
    BywinCloudPageResponse<SysUser> listUserBySearchPage(@RequestBody SysUserSearchRequest params) {
        return userClient.listUserBySearchPage(params);
    }

    /**
     * 全部用户列表
     */
    @GetMapping("/user/listAllUser")
    BywinCloudResponse<List<SysUser>> listAllUser() {
        return userClient.listAllUser();
    }

    /**
     * 根据userId获取用户
     *
     * @param userId
     * @return
     */
    @PostMapping("/user/getUserById")
    BywinCloudResponse<SysUser> getUserById(@RequestParam("userId") String userId) {
        return userClient.getUserById(userId);
    }

    /**
     * 根据手机号获取用户
     *
     * @param phonenumber
     * @return
     */
    @PostMapping("/user/getUserByPhonenumber")
    BywinCloudResponse<SysUser> getUserByPhonenumber(@RequestParam("phonenumber") String phonenumber) {
        return userClient.getUserByPhonenumber(phonenumber);
    }

    /**
     * 根据username获取用户
     *
     * @param userName
     * @return
     */
    @PostMapping("/user/getUserByName")
    BywinCloudResponse<SysUser> getUserByName(@RequestParam("userName") String userName) {
        return userClient.getUserByName(userName);
    }

    /**
     * 编辑用户
     *
     * @param user
     * @return
     */
    @PutMapping("/user")
    BywinCloudResponse edit(@RequestBody SysUser user) {
        return userClient.edit(user);
    }

    /**
     * 更新用户
     *
     * @param user
     * @return
     */
    @PostMapping("/user")
    BywinCloudResponse add(@RequestBody SysUser user) {
        return userClient.add(user);
    }

    /**
     * 删除用户
     *
     * @param userIds
     * @return
     */
    @DeleteMapping("/user/{userIds}")
    BywinCloudResponse remove(@PathVariable("userIds") Long[] userIds) {
        return userClient.remove(userIds);
    }

    /**
     * 根据角色key 获取底下的搜索授权用户列表
     */
    @GetMapping("/user/listByRoleKey/{roleKey}")
    BywinCloudResponse<List<SysUser>> userListByRoleKey(@PathVariable("roleKey") String roleKey) {
        return userClient.userListByRoleKey(roleKey);
    }

    /**
     * 根据角色id或部门id 获取底下的搜索授权用户列表
     */
    @PostMapping("/user/getUserIdByRoleIdOrDeptId/post")
    BywinCloudResponse<List<SysUser>> getUserIdByRoleIdOrDeptIdPost(@RequestBody SysUserRole sysUserRole) {
        return userClient.getUserIdByRoleIdOrDeptIdPost(sysUserRole);
    }

    //userRole相关

    /**
     * 获取用户与角色和部门的关系 根据userId
     */
    @PostMapping("/user/listUserRoleByUserId")
    BywinCloudResponse<List<SysUserRole>> listUserRoleByUserId(@RequestParam("userId") String userId) {
        return userClient.listUserRoleByUserId(userId);
    }

    /**
     * 获取用户与角色和部门的关系 根据应用id,角色id
     */
    @PostMapping("/user/listUserRoleByRoleIdAndAppId")
    BywinCloudResponse<List<SysUserRole>> listUserRoleByRoleIdAndAppId(@RequestBody SysUserRole userRole) {
        return userClient.listUserRoleByRoleIdAndAppId(userRole);
    }

    /**
     * 批量新增用户授权
     *
     * @param list
     * @return
     */
    @PostMapping("/user/batchAppListUserRoleR")
    BywinCloudResponse<List<SysUserRole>> batchAppListUserRoleR(@RequestBody List<SysUserRole> list) {
        return userClient.batchAppListUserRoleR(list);
    }

    /**
     * 批量更新用户授权
     */
    @PostMapping("/user/editUserRoleDeptApp")
    BywinCloudResponse<Map<String, List<SysUserRole>>> editUserRoleDeptApp(@RequestBody SysUserRoleAppDeptRequest userRoleAppDeptVO) {
        return userClient.editUserRoleDeptApp(userRoleAppDeptVO);
    }

    /**
     * 批量删除用户授权
     *
     * @param sysUserRole
     * @return
     */
    @PostMapping("/user/deleteAppUserRole")
    BywinCloudResponse<?> deleteAppUserRole(@RequestBody List<SysUserRole> sysUserRole) {
        return userClient.deleteAppUserRole(sysUserRole);
    }
}