package com.example.bywin.cloud.server.example.modules.usermanager.api;

import com.bywin.cloud.boot.annatation.BywinCloudRest;
import com.bywin.cloud.entity.standard.page.IPageData;
import com.bywin.cloud.security.core.access.RequiredBywinCloudPermissions;
import com.example.bywin.cloud.server.example.modules.usermanager.biz.ExampleUserManager;
import com.example.bywin.cloud.server.example.modules.usermanager.consts.UserManagerPermissions;
import com.example.bywin.cloud.server.example.modules.usermanager.request.CreateUserRequest;
import com.example.bywin.cloud.server.example.modules.usermanager.request.QueryUserRequest;
import com.example.bywin.cloud.server.example.modules.usermanager.request.UpdateUserRequest;
import com.example.bywin.cloud.server.example.modules.usermanager.tb.ExampleUser;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.enums.ParameterIn;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

/**
 * @author xie40
 * create time: 2023-06-29 15:08
 */
@Tag(name = "用户管理模块示例")
@BywinCloudRest("/users")
@RequiredArgsConstructor
public class ExampleUserManagerApi {

    private final ExampleUserManager exampleUserManager;

    @GetMapping("/{userId}")
    @Operation(summary = "根据用户id查询用户信息")
    @RequiredBywinCloudPermissions(UserManagerPermissions.QUERY_USER)
    public ExampleUser getUserInfoById(
            @Parameter(in = ParameterIn.PATH, description = "用户id")
            @PathVariable("userId") Long userId) {
        return exampleUserManager.getUserById(userId);
    }

    @PostMapping
    @Operation(summary = "新建用户信息/返回id")
    @RequiredBywinCloudPermissions(UserManagerPermissions.ADD_USER)
    public Long createUser(@RequestBody @Valid CreateUserRequest createUserRequest) {
        return exampleUserManager.createUser(createUserRequest);
    }

    @PutMapping
    @Operation(summary = "修改用户信息")
    @RequiredBywinCloudPermissions(UserManagerPermissions.UPDATE_USER)
    public void updateUser(@RequestBody @Valid UpdateUserRequest updateUserRequest) {
        exampleUserManager.updateUser(updateUserRequest);
    }

    @DeleteMapping("/{userId}")
    @Operation(summary = "根据id删除用户")
    @RequiredBywinCloudPermissions(UserManagerPermissions.DEL_USER)
    public void delUserById(
            @Parameter(in = ParameterIn.PATH, description = "用户id")
            @PathVariable("userId") Long userId) {
        exampleUserManager.delUserById(userId);
    }

    @PostMapping("/search")
    @Operation(summary = "分页查询用户，不需要权限")
    @RequiredBywinCloudPermissions(UserManagerPermissions.QUERY_USER)
    public IPageData<ExampleUser> pageQueryUsers(@Valid @RequestBody QueryUserRequest query) {
        return exampleUserManager.pageQueryUsers(query);
    }

}
