package com.example.bywin.cloud.server.example.modules.usermanager.biz;

import com.bywin.cloud.entity.standard.page.IPageData;
import com.bywin.cloud.exception.BywinCloudRuntimeException;
import com.example.bywin.cloud.server.example.modules.usermanager.repository.ExampleUserRepository;
import com.example.bywin.cloud.server.example.modules.usermanager.request.CreateUserRequest;
import com.example.bywin.cloud.server.example.modules.usermanager.request.QueryUserRequest;
import com.example.bywin.cloud.server.example.modules.usermanager.request.UpdateUserRequest;
import com.example.bywin.cloud.server.example.modules.usermanager.response.ExampleUserSimpleInfo;
import com.example.bywin.cloud.server.example.modules.usermanager.tb.ExampleUser;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.Date;

/**
 * example 用户管理/业务层代码
 *
 * @author xie40
 * create time: 2023-06-08 16:36
 */
@Slf4j
@Service
@RequiredArgsConstructor
@SuppressWarnings("unchecked")
public class ExampleUserManager {

    private final ExampleUserRepository repository;

    public ExampleUserSimpleInfo getUserSimpleInfo(Long userId) {

        final ExampleUser user = repository.getUserById(userId,
                ExampleUser::getId,
                ExampleUser::getUsername,
                ExampleUser::getDeptId);

        return ExampleUserSimpleInfo.of(user);
    }

    public ExampleUser getUserById(Long userId) {
        return repository.getById(userId);
    }


    public Long createUser(CreateUserRequest createUserRequest) {

        if (repository.existsUsername(createUserRequest.getUsername())) {

            throw new BywinCloudRuntimeException("用户名: {0}, 已存在", createUserRequest.getUsername());
        }

        final ExampleUser exampleUser = createUserRequest.toExampleUser();

        exampleUser.setExpireTime(new Date());
        repository.save(exampleUser);
        return exampleUser.getId();

    }

    public void updateUser(UpdateUserRequest updateUserRequest) {

        if (repository.existsUsername(updateUserRequest.getUsername(), updateUserRequest.getId())) {

            throw new BywinCloudRuntimeException("用户名: {0}, 已存在", updateUserRequest.getUsername());
        }


        final ExampleUser oldUser = repository.getById(updateUserRequest.getId());

        if (oldUser == null) {
            throw new BywinCloudRuntimeException("用户id: {0}, 不存在", updateUserRequest.getId());
        }

        updateUserRequest.updateTo(oldUser);
        repository.save(oldUser);

    }

    public void delUserById(Long userId) {
        repository.removeById(userId);
    }

    /**
     * 分页查询
     *
     * @param request 用户信息
     */
    public IPageData<ExampleUser> pageQueryUsers(QueryUserRequest request) {
        return repository.pageQuery(request);
    }

}
