package com.example.bywin.cloud.server.example.modules.usermanager.repository;

import com.baomidou.mybatisplus.core.toolkit.support.SFunction;
import com.baomidou.mybatisplus.extension.conditions.query.LambdaQueryChainWrapper;
import com.bywin.cloud.entity.standard.page.IPageData;
import com.bywin.cloud.mybatis.pagehelper.BywinCloudPageHelper;
import com.bywin.cloud.mybatis.plus.repository.IBywinCloudDataPermitRepository;
import com.bywin.cloud.security.core.datascope.annotations.InjectBywinCloudDataPermit;
import com.example.bywin.cloud.server.example.modules.usermanager.request.QueryUserRequest;
import com.example.bywin.cloud.server.example.modules.usermanager.tb.ExampleUser;
import org.apache.commons.lang3.StringUtils;

import java.util.List;
import java.util.Optional;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * example 用户管理数据库访问层代码
 *
 * @author hxl
 * create time: 2023-06-08 16:36
 */
public interface ExampleUserRepository extends IBywinCloudDataPermitRepository<ExampleUser> {

    /**
     * 数据权限字段，数据拥有者字段。
     */
    @Override
    default SFunction<ExampleUser, ?> getOwnerLambdaColumn() {
        return ExampleUser::getCreateBy;
    }


    default ExampleUser getUserById(Long userId, SFunction<ExampleUser, ?>... cols) {
        return lambdaQuery()
                .select(cols)
                .eq(ExampleUser::getId, userId)
                .one();
    }

    default boolean existsUsername(String username, Long... ignoredIds) {
        final List<Long> ignoredIdSet = Stream.of(ignoredIds).collect(Collectors.toList());
        return lambdaQuery()
                .select(ExampleUser::getId)
                .eq(ExampleUser::getUsername, username)
                .notIn(!ignoredIdSet.isEmpty(), ExampleUser::getId, ignoredIdSet)
                .exists();
    }

    /**
     * 使用 InjectBywinCloudDataPermit 注解注入权限
     *
     * @param request QueryUserRequest
     * @return inject(wrapper, BywinCloudDataPermitContextHolder.permit ());
     */
    @InjectBywinCloudDataPermit
    default LambdaQueryChainWrapper<ExampleUser> lambdaQuery(QueryUserRequest request) {
        final String username = Optional.ofNullable(request.getUsername()).map(String::trim).orElse(null);
        return lambdaQuery().like(StringUtils.isNotBlank(username), ExampleUser::getUsername, username);
    }

    default IPageData<ExampleUser> pageQuery(QueryUserRequest request) {

        // aop不支持 内部调用代理方法，所以这里用self(this)转成代理类
        final LambdaQueryChainWrapper<ExampleUser> wrapper = self(this).lambdaQuery(request);
        return BywinCloudPageHelper.query(request, wrapper::list);
    }

}
