package com.example.bywin.cloud.server.example.responsewrapper;

import com.bywin.cloud.boot.annatation.BywinCloudResponseWrapper;
import com.bywin.cloud.boot.annatation.BywinCloudRest;
import com.bywin.cloud.boot.annatation.UnwrapBywinCloudResponse;
import com.bywin.cloud.entity.standard.web.IBywinCloudRestReturnValueWrapper;
import com.bywin.cloud.web.response.BywinCloudResponse;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.GetMapping;

import java.util.HashMap;

/**
 * 响应包裹测试示例
 *
 * @author xie40
 * create time: 2023-07-10 17:24
 */
@BywinCloudRest("/response-wrapper")
@Tag(name = "响应包裹测试")
public class ResponseWrapperExampleApi {

    @Operation(summary = "指定code，msg")
    @GetMapping("/test-code-msg")
    public BywinCloudResponse<String> codeMsg() {

        final BywinCloudResponse<String> response = new BywinCloudResponse<>();

        response.setCode(120);
        response.setMsg("my msg");
        response.setData("hello world!");

        return response;
    }

    @Operation(summary = "测试包裹响应类型(默认)")
    @GetMapping("/test-wrap")
    public String testWrap() {
        //noinspection SpringMVCViewInspection
        return "test wrap";
    }

    /**
     * 使用 @UnwrapBywinCloudResponse 注解取消包裹
     */
    @UnwrapBywinCloudResponse
    @Operation(summary = "测试不包裹响应类型，适用于响应文件")
    @GetMapping("/test-unwrap")
    public String testUnwrap() {
        //noinspection SpringMVCViewInspection
        return "test unwrap";
    }

    public static class MyResponseWrapper implements IBywinCloudRestReturnValueWrapper {

        @Override
        public Object wrap(Object returnValue) {
            final HashMap<String, Object> wrappered = new HashMap<>();
            wrappered.put("data", returnValue);
            wrappered.put("mywrapper", "this is my wrapper");
            return wrappered;
        }

    }

    /**
     * 使用 @BywinCloudResponseWrapper 包裹
     */
    @Operation(summary = "测试自定义包裹响应类型")
    @BywinCloudResponseWrapper(type = MyResponseWrapper.class)
    @GetMapping("/test-custom-wrap")
    public String testCustomWrapper() {
        //noinspection SpringMVCViewInspection
        return "testCustomWrapper";
    }
}
