package com.example.bywin.cloud.server.file.example.api;

import com.bywin.cloud.boot.annatation.BywinCloudRest;
import com.bywin.cloud.client.services.clients.file.BywinCloudFileClient;
import com.bywin.cloud.client.services.clients.file.domain.FileInfo;
import com.bywin.cloud.client.services.clients.file.request.FileDeleteParams;
import com.bywin.cloud.web.response.BywinCloudResponse;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @author xie40
 * create time: 2023-06-15 16:20
 */
@Slf4j
@Tag(name = "文件上传client调用")
@BywinCloudRest(value = "/example")
@RequiredArgsConstructor
public class FileClientExampleApi {
    private final BywinCloudFileClient bywinCloudFileClient;

    /**
     * 新增文件 BywinCloudResponse<String> 文件id
     */
    @Operation(summary = "新增文件")
    @PostMapping(value = "/file/add", consumes = MediaType.MULTIPART_FORM_DATA_VALUE)
    public BywinCloudResponse<String> add(@RequestPart(value = "file") MultipartFile file) {
        return bywinCloudFileClient.add(file);
    }

    /**
     * 上传文件 BywinCloudResponse<String>
     */
    @Operation(summary = "上传文件")
    @PostMapping(value = "/file/upload", consumes = MediaType.MULTIPART_FORM_DATA_VALUE)
    public BywinCloudResponse<String> upload(@RequestPart(value = "file") MultipartFile file) {
        return bywinCloudFileClient.upload(file);
    }

    /**
     * 删除文件 BywinCloudResponse<?>
     */
    @Operation(summary = "删除文件")
    @PostMapping("/file/remove")
    public BywinCloudResponse<?> remove(@RequestBody FileDeleteParams params) throws Exception {
        //d4c11f2b5ac246dd9d8151c83c862afb
        return bywinCloudFileClient.remove(params);
    }

    /**
     * 获取文件 BywinCloudResponse<FileInfo>
     */
    @Operation(summary = "获取文件")
    @GetMapping("/file/getInfo")
    public BywinCloudResponse<FileInfo> getInfo(@RequestParam("id") String id) {
        return bywinCloudFileClient.getInfo(id);
    }

    /**
     * 批量获取文件 BywinCloudResponse<List < FileInfo>>
     */
    @Operation(summary = "批量获取文件")
    @GetMapping("/file/getInfos")
    public BywinCloudResponse<List<FileInfo>> getInfos(@RequestParam("ids") String ids) {
        return bywinCloudFileClient.getInfos(ids);
    }

    /**
     * 获取文件预览url BywinCloudResponse<?>
     */
    @Operation(summary = "获取文件预览url")
    @GetMapping("/file/viewUrl")
    public BywinCloudResponse<?> getViewUrl(@RequestParam("id") String id) {
        return bywinCloudFileClient.getViewUrl(id);
    }
}
