package com.example.bywin.cloud.server.msg.example.api;

import com.bywin.cloud.boot.annatation.BywinCloudRest;
import com.bywin.cloud.client.services.clients.msg.BywinCloudMsgClient;
import com.bywin.cloud.client.services.clients.msg.domain.MessageCenterChannelVO;
import com.bywin.cloud.web.response.BywinCloudResponse;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * @author xie40
 * create time: 2023-06-15 16:20
 */
@Slf4j
@Tag(name = "msgClient调用")
@BywinCloudRest(value = "/example")
@RequiredArgsConstructor
public class MsgClientExampleApi {
    private final BywinCloudMsgClient bywinCloudMsgClient;

    /**
     * 发送邮箱单个 BywinCloudResponse<?>
     */
    @Operation(summary = "发送邮箱单个")
    @PostMapping("/mail/sendEmailSingle")
    public BywinCloudResponse<?> sendEmailSingle() {
        String sendTo = "903133815@qq.com";
        String content = "example content";
        String preKey = "email prefix redis key-"; //检测频繁调用前缀key
        long timeout = 2000; //判定频繁调用的间隔

        return bywinCloudMsgClient.sendEmailSingle(sendTo, content, preKey, timeout);
    }

    /**
     * 发送短信单个 BywinCloudResponse<?>
     */
    @Operation(summary = "发送短信单个")
    @PostMapping("/mail/sendSMSSingle")
    public BywinCloudResponse<?> sendSMSSingle() {
        String sendTo = "15559554510";
        String content = "1234";
        String preKey = "sms prefix redis key-"; //检测频繁调用前缀key
        long timeout = 2000; //判定频繁调用的间隔
        return bywinCloudMsgClient.sendSMSSingle(sendTo, content, preKey, timeout);
    }

    /**
     * 发送邮箱 BywinCloudResponse<?>
     */
    @Operation(summary = "发送邮箱")
    @PostMapping("/mail/sendMail")
    public BywinCloudResponse<?> sendEmail(@RequestParam("sendTo") String[] sendTo, @RequestParam("subject") String subject, @RequestParam("content") String content, @RequestParam(value = "files", required = false) MultipartFile[] files) throws Exception {
        //sendTo = new String[]{"username1", "username2"};
        //subject = "subject";
        //content = "example content";
        //files = null;
        return bywinCloudMsgClient.sendEmail(sendTo, subject, content, files);
    }

    /**
     * 发送短信 BywinCloudResponse<?>
     */
    @Operation(summary = "发送短信")
    @PostMapping("/mail/sendSMS")
    public BywinCloudResponse<?> sendSMS(@RequestParam("sendTo") String[] sendTo, @RequestParam("content") String content) throws Exception {
        //sendTo = new String[]{"username1", "username2"};
        //content = "subject";
        return bywinCloudMsgClient.sendSMS(sendTo, content);
    }

    /**
     * 消息通道列表 BywinCloudResponse<List < MessageCenterChannelVO>>
     */
    @Operation(summary = "消息通道列表")
    @GetMapping("/message/channel/listAll")
    public BywinCloudResponse<List<MessageCenterChannelVO>> channelListAll() {
        return bywinCloudMsgClient.channelListAll();
    }

}
