package com.example.bywin.cloud.server.notice.example.api;

import com.bywin.cloud.boot.annatation.BywinCloudRest;
import com.bywin.cloud.client.services.clients.notice.BywinCloudNoticeClient;
import com.bywin.cloud.client.services.clients.notice.domain.GgInfo;
import com.bywin.cloud.client.services.clients.notice.request.NoticeListParams;
import com.bywin.cloud.web.response.BywinCloudPageResponse;
import com.bywin.cloud.web.response.BywinCloudResponse;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

/**
 * @author xie40
 * create time: 2023-06-15 16:21
 */
@Slf4j
@Tag(name = "noticeClient调用")
@BywinCloudRest(value = "/example")
@RequiredArgsConstructor
public class NoticeClientExampleApi {
    private final BywinCloudNoticeClient bywinCloudNoticeClient;

    /**
     * 通知列表 BywinCloudPageResponse<?>
     */
    @Operation(summary = "通知列表")
    @GetMapping("/ggRead/userNoticeList2")
    public BywinCloudPageResponse<?> userNoticeList2(NoticeListParams params) {
        return bywinCloudNoticeClient.userNoticeList2(params);
    }


    /**
     * 保存通知 BywinCloudResponse<GgInfo>
     */
    @Operation(summary = "保存通知")
    @PostMapping("/ggInfo/save")
    public BywinCloudResponse<GgInfo> save(@RequestBody GgInfo ggInfo) {
        return bywinCloudNoticeClient.save(ggInfo);
    }

    /**
     * 删除通知 BywinCloudResponse<?>
     */
    @Operation(summary = "删除通知")
    @GetMapping("/ggInfo/delete/{id}")
    public BywinCloudResponse<?> delete(@PathVariable("id") Long id, @RequestParam(value = "appId", required = false) Long appId) {
        return bywinCloudNoticeClient.delete(id, appId);
    }

    /**
     * 通知置为已读 BywinCloudResponse<GgInfo>
     */
    @Operation(summary = "通知置为已读")
    @GetMapping("/ggRead/viewNoticeApi")
    public BywinCloudResponse<GgInfo> viewNoticeApi(@RequestParam("id") Long id) {
        //id是公告阅读记录的id

        return bywinCloudNoticeClient.viewNoticeApi(id);
    }
}
