package com.example.bywin.cloud.server.rbac.example.api;

import com.bywin.cloud.boot.annatation.BywinCloudRest;
import com.bywin.cloud.client.services.clients.system.BywinCloudSystemMenuClient;
import com.bywin.cloud.client.services.clients.system.domain.SysMenu;
import com.bywin.cloud.web.response.BywinCloudResponse;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.SpringQueryMap;
import org.springframework.web.bind.annotation.*;

@Slf4j
@Tag(name = "认证菜单示例api")
@BywinCloudRest(value = "/example")
@RequiredArgsConstructor
public class SystemMenuExampleApi {
    private final BywinCloudSystemMenuClient menuClient;

    /**
     * 菜单列表
     * @param menu
     * @return
     */
    @GetMapping("/menu/list")
    BywinCloudResponse<?> list(@SpringQueryMap SysMenu menu) {
        menu.setApplicationId(0L);
        return menuClient.list(menu);
    }

    /**
     * 添加菜单
     * @param menu
     * @return
     */
    @PostMapping("/menu")
    BywinCloudResponse<Long> add(@RequestBody SysMenu menu) {
        return menuClient.add(menu);
    }

    /**
     * 更新菜单
     * @param menu
     * @return
     */
    @PutMapping("/menu")
    BywinCloudResponse<?> edit(@RequestBody SysMenu menu) {
        return menuClient.edit(menu);
    }

    /**
     * 删除菜单
     * @param menuId
     * @param applicationId
     * @return
     */
    @DeleteMapping("/menu/{menuId}")
    BywinCloudResponse<?> remove(@PathVariable("menuId") Long menuId, @RequestParam(value = "applicationId", required = false) Long applicationId) {
        return menuClient.remove(menuId, applicationId);
    }

}

