package com.example.bywin.cloud.server.rbac.example.api;

import com.bywin.cloud.boot.annatation.BywinCloudRest;
import com.bywin.cloud.client.services.clients.system.BywinCloudSystemRoleClient;
import com.bywin.cloud.client.services.clients.system.domain.SysRole;
import com.bywin.cloud.web.response.BywinCloudPageResponse;
import com.bywin.cloud.web.response.BywinCloudResponse;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.SpringQueryMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Slf4j
@Tag(name = "认证角色示例api")
@BywinCloudRest(value = "/example")
@RequiredArgsConstructor
public class SystemRoleExampleApi {
    private final BywinCloudSystemRoleClient roleClient;

    /**
     * 角色列表
     * @param sysRole
     * @return
     */
    @GetMapping("/role/listR")
    BywinCloudPageResponse<?> list(@SpringQueryMap SysRole sysRole) {
        sysRole.setApplicationId(0L);

        return roleClient.list(sysRole);
    }

    /**
     * 根据角色key 获取角色
     * @param roleKey
     * @return
     */
    @GetMapping("/role/getRoleInfo/{roleKey}")
    SysRole getRoleInfo(@PathVariable("roleKey") String roleKey) {
        return roleClient.getRoleInfo(roleKey);
    }

    /**
     * 根据角色id 获取角色
     * @param roleId
     * @return
     */
    @GetMapping("/role/getRoleInfoByRoleId/{roleId}")
    SysRole getRoleInfoByRoleId(@PathVariable("roleId") Long roleId) {
        return roleClient.getRoleInfoByRoleId(roleId);
    }

    /**
     * 添加角色
     * @param role
     * @return
     */
    @PostMapping("/role")
    BywinCloudResponse<Long> add(@RequestBody SysRole role) {
        return roleClient.add(role);
    }

    /**
     * 更新角色
     * @param role
     * @return
     */
    @PutMapping("/role")
    BywinCloudResponse<?> edit(@RequestBody SysRole role) {
        return roleClient.edit(role);
    }

    /**
     * 删除角色
     * @param roleIds
     * @param applicationId
     * @return
     */
    @DeleteMapping("/role/{roleIds}")
    BywinCloudResponse<?> remove(@PathVariable("roleIds") Long[] roleIds, @RequestParam(value = "applicationId", required = false) Long applicationId) {
        return roleClient.remove(roleIds, applicationId);
    }

    /**
     * 获取某个username的所有授权角色
     * @param userName
     * @return
     */
    @GetMapping("/role/selectRolesByUserName/{userName}")
    BywinCloudResponse<List<SysRole>> selectRolesByUserName(@PathVariable("userName") String userName) {
        return roleClient.selectRolesByUserName(userName);
    }

}

