package com.example.bywin.cloud.server.workflow.example.api;

import com.bywin.cloud.boot.annatation.BywinCloudRest;
import com.bywin.cloud.client.services.clients.workflow.BywinCloudWorkflowClient;
import com.bywin.cloud.client.services.clients.workflow.constant.FlowConstants;
import com.bywin.cloud.client.services.clients.workflow.request.ChooseAssigneeRequest;
import com.bywin.cloud.client.services.clients.workflow.request.TaskActionRequest;
import com.bywin.cloud.client.services.clients.workflow.request.TaskProcessRequest;
import com.bywin.cloud.client.services.clients.workflow.response.*;
import com.bywin.cloud.web.response.BywinCloudResponse;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.SpringQueryMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Slf4j
@Tag(name = "工作流client调用")
@BywinCloudRest(value = "/")
@RequiredArgsConstructor
public class WorkFlowClientExampleController {
    private final BywinCloudWorkflowClient bywinCloudWorkflowClient;

    /**
     * 查询流程审批意见
     *
     * @param processInstanceId 流程实例id
     * @return 审批意见列表
     */
    @GetMapping("/workFlow/viewTask")
    BywinCloudResponse<List<TaskComment>> viewTask(@RequestParam(FlowConstants.PROCESS_INSTANCE_ID_FIELD) String processInstanceId) {
        return bywinCloudWorkflowClient.viewTask(processInstanceId);
    }

    /**
     * 查询当前登陆用户在当前流程实例的权限
     *
     * @param processInstanceId 流程实例id
     * @param listType          列表类型 0.发起 1.待办 2.已办 3抄送
     * @return 权限信息
     */
    @Operation(summary = "删除流程示例")
    @PostMapping("/workFlow/authority")
    BywinCloudResponse<TaskAuthority> authority(@RequestParam(FlowConstants.PROCESS_INSTANCE_ID_FIELD) String processInstanceId,
                                                @RequestParam(FlowConstants.KEY_LIST_TYPE) Object listType) {
        return bywinCloudWorkflowClient.authority(processInstanceId, listType);
    }

    /**
     * 删除流程示例
     *
     * @param processInstanceId 流程实例id
     * @return 操作结果
     */
    @Operation(summary = "删除流程示例")
    @PostMapping("/workFlow/delTask")
    public BywinCloudResponse<Void> delTask(@RequestParam(FlowConstants.PROCESS_INSTANCE_ID_FIELD) String processInstanceId) {
        return bywinCloudWorkflowClient.delTask(processInstanceId);
    }

    /**
     * 流程审批操作
     *
     * @param request 流程审批操作实体类
     * @return 节点信息
     */
    @PostMapping("/workFlow/taskAction")
    public BywinCloudResponse<TaskMeta> taskAction(@RequestBody TaskActionRequest request) {
        return bywinCloudWorkflowClient.taskAction(request);
    }

    /**
     * 查询节点候选人
     *
     * @param request 请求体
     * @return 候选人信息
     */
    @PostMapping("/workFlow/chooseAssignee")
    public BywinCloudResponse<Assignees> chooseAssignee(@RequestBody ChooseAssigneeRequest request) {
        return bywinCloudWorkflowClient.chooseAssignee(request);
    }

    /**
     * 查询用户相关流程实例id列表
     *
     * @param request 请求体
     * @return 流程实例id列表
     */
    @GetMapping("/workFlow/listYw")
    public BywinCloudResponse<List<String>> taskProcessList(@SpringQueryMap TaskProcessRequest request) {
        return bywinCloudWorkflowClient.taskProcessList(request);
    }

    /**
     * 根据分类查询流程信息
     *
     * @param typeName 分类名称
     * @param proName  流程名称
     * @return 流程列表信息
     */
    @GetMapping("/workFlow/procList")
    BywinCloudResponse<List<ProcInfo>> procList(@RequestParam("typeName") String typeName, @RequestParam(value = "procName", required = false) String proName) {
        return bywinCloudWorkflowClient.procList(typeName, proName);
    }

    /**
     * 查询流程可退回节点列表
     *
     * @param processInstanceId 流程实例id
     * @return 可退回列表
     */
    @GetMapping("/workFlow/rejectTaskList")
    BywinCloudResponse<List<TaskReject>> rejectTaskList(@RequestParam(FlowConstants.PROCESS_INSTANCE_ID_FIELD) String processInstanceId) {
        return bywinCloudWorkflowClient.rejectTaskList(processInstanceId);
    }
}
