package com.example.bywin.cloud.server.workflow.example.repository.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.bywin.cloud.client.services.clients.workflow.BywinCloudWorkflowClient;
import com.bywin.cloud.client.services.clients.workflow.request.TaskActionRequest;
import com.bywin.cloud.client.services.clients.workflow.request.TaskProcessRequest;
import com.bywin.cloud.client.services.clients.workflow.response.AuthorityCheck;
import com.bywin.cloud.client.services.clients.workflow.response.TaskAuthority;
import com.bywin.cloud.client.services.clients.workflow.response.TaskMeta;
import com.bywin.cloud.entity.standard.page.IPageData;
import com.bywin.cloud.exception.BywinCloudRuntimeException;
import com.bywin.cloud.mybatis.pagehelper.BywinCloudPageHelper;
import com.bywin.cloud.web.response.BywinCloudResponse;
import com.example.bywin.cloud.server.workflow.example.constants.FlowList;
import com.example.bywin.cloud.server.workflow.example.mapper.LeaveApplyMapper;
import com.example.bywin.cloud.server.workflow.example.repository.LeaveApplyService;
import com.example.bywin.cloud.server.workflow.example.tb.LeaveApply;
import com.example.bywin.cloud.server.workflow.example.tb.LeaveApplySearchParams;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.util.*;
import java.util.stream.Collectors;

@Service
public class LeaveApplyServiceImpl extends ServiceImpl<LeaveApplyMapper, LeaveApply> implements LeaveApplyService {

    @Autowired
    private BywinCloudWorkflowClient workflowClient;

    /**
     * 批量校验节点权限
     */
    private void checkAuthBatch(@SuppressWarnings("rawtypes") List varList, Object listType) {
        try {
            List<String> processInstanceIds = new ArrayList<>();
            for (Object obj : varList) {
                Class<?> clz = obj.getClass();
                Method processInstanceId = clz.getMethod("getProcessInstanceId");
                Object procInstId = processInstanceId.invoke(obj);
                if (procInstId != null) {
                    processInstanceIds.add(procInstId.toString());
                }
            }
            List<AuthorityCheck> authorityList = workflowClient.authorityList(processInstanceIds, listType).getData();

            Map<String, TaskAuthority> map = authorityList.parallelStream().collect(Collectors.toMap(AuthorityCheck::getProcessInstanceId, AuthorityCheck::getAuthority, (s, s2) -> s));

            for (Object obj : varList) {
                Class<?> clz = obj.getClass();
                Field authority = clz.getDeclaredField("authority");
                authority.setAccessible(true);

                Method processInstanceId = clz.getMethod("getProcessInstanceId");
                Object procInstId = processInstanceId.invoke(obj);

                authority.set(obj, map.get(procInstId.toString()));
            }


        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    public IPageData<LeaveApply> queryPage(LeaveApplySearchParams params) {
        LambdaQueryWrapper<LeaveApply> qw = new LambdaQueryWrapper<>();

        //接入工作流
        TaskProcessRequest workFlowParams = new TaskProcessRequest();
        workFlowParams.setTypeName("SDK测试分类");
        workFlowParams.setListType(params.getListType());
        List<String> instIdList = workflowClient.taskProcessList(workFlowParams).getData();
        qw.in(ObjectUtils.isNotNull(instIdList), LeaveApply::getProcessInstanceId, instIdList);

        IPageData<LeaveApply> ret = BywinCloudPageHelper.query(params, () -> list(qw));
        checkAuthBatch(ret.getRows(), params.getListType());
        return ret;
    }


    @Override
    public void add(LeaveApply info) {
        save(info);

        //接入工作流
        TaskActionRequest processParam = info.getProcessParam();
        processParam.setId(info.getId());
        processParam.setBusinessKey("leave apply:" + info.getId());
        taskAction(processParam, info);
    }

    private void taskAction(TaskActionRequest processParam, LeaveApply info) {
        BywinCloudResponse<TaskMeta> ret = workflowClient.taskAction(processParam);

        if (ret.getCode() != 0) {
            throw new BywinCloudRuntimeException(ret.getMsg());
        }

        // 获取当前节点的审批信息，存储到业务表中
        TaskMeta taskMeta = ret.getData();
        BeanUtils.copyProperties(taskMeta, info);
        updateById(info);
    }

    @Override
    public void update(LeaveApply info) {
        updateById(info);

        //接入工作流
        TaskActionRequest processParam = info.getProcessParam();
        processParam.setId(info.getId());
        processParam.setBusinessKey("leave apply:" + info.getId());
        processParam.setProcessInstanceId(info.getProcessInstanceId());
        taskAction(processParam, info);
    }

    @Override
    public LeaveApply getInfo(Long id) {
        LeaveApply info = getById(id);

        //工作流节点权限
        TaskAuthority authority = workflowClient.authority(info.getProcessInstanceId(), FlowList.ALL.getCode()).getData();
        info.setAuthority(authority);

        return info;
    }

    @Override
    public void delete(Long[] ids) {
        List<Long> idList = Arrays.asList(ids);

        if (!idList.isEmpty()) {
            List<LeaveApply> list = list(new LambdaQueryWrapper<LeaveApply>()
                    .in(LeaveApply::getId, idList));

            for (LeaveApply d : list) {
                if (StringUtils.isNotBlank(d.getProcessInstanceId())) {
                    //删除工作流数据
                    try {
                        workflowClient.delTask(d.getProcessInstanceId());
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            }

            removeByIds(idList);
        }
    }
}
